@@ -133,7 +133,13 @@ extern JUCE_API void *attachComponentToWindowRefVST(Component *, void *parentWin
 } // namespace juce
 #endif
 
-JUCE_BEGIN_IGNORE_WARNINGS_MSVC(4996) // allow strncpy
+// Some compilers generate warnings when we use `strncpy` instead
+// of `strncpy_s`. However, other compilers don't support `strncpy_s`.
+// So for now, we ignore those warnings, but once all the compilers
+// that we care about support `strncpy_s`, we should remove these
+// warnings guards and use `strncpy_s`.
+JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE("-Wdeprecated-declarations")
+JUCE_BEGIN_IGNORE_WARNINGS_MSVC(4996)
 
 #if !defined(CLAP_MISBEHAVIOUR_HANDLER_LEVEL)
 #define CLAP_MISBEHAVIOUR_HANDLER_LEVEL "Ignore"
@@ -362,6 +368,12 @@ class EditorHostContext : public juce::AudioProcessorEditorHostContext
 };
 #endif // JUCE_VERSION >= 0x060008
 
+/** Converts a clap_color to a juce::Colour */
+static juce::Colour clapColourToJUCEColour(const clap_color &clapColour)
+{
+    return {clapColour.red, clapColour.green, clapColour.blue, clapColour.alpha};
+}
+
 /*
  * The ClapJuceWrapper is a class which immplements a collection
  * of CLAP and JUCE APIs
@@ -776,6 +788,11 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
                                        CLAP_BEATTIME_FACTOR);
                 posinfo.setPpqPositionOfLastBarStart(1.0 * (double)transportInfo->bar_start /
                                                      CLAP_BEATTIME_FACTOR);
+                juce::AudioPlayHead::LoopPoints loopPoints {
+                    1.0 * (double) transportInfo->loop_start_beats / CLAP_BEATTIME_FACTOR,
+                    1.0 * (double) transportInfo->loop_end_beats / CLAP_BEATTIME_FACTOR
+                };
+                posinfo.setLoopPoints(loopPoints);
             }
             if (flags & CLAP_TRANSPORT_HAS_SECONDS_TIMELINE)
             {
@@ -908,6 +925,13 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
             info->flags = 0;
         }
 
+        if (processor->supportsDoublePrecisionProcessing())
+        {
+            info->flags |= CLAP_AUDIO_PORT_SUPPORTS_64BITS;
+            info->flags |= CLAP_AUDIO_PORT_PREFERS_64BITS;
+            info->flags |= CLAP_AUDIO_PORT_REQUIRES_COMMON_SAMPLE_SIZE;
+        }
+
         if (processor->getBus(!isInput, (int)index) != nullptr)
         {
             // this bus has a corresponding bus on the other side, so it can do in-place processing
@@ -1045,6 +1069,75 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
         return false;
     }
 
+    bool implementsTrackInfo() const noexcept override { return true; }
+
+    void trackInfoChanged() noexcept override
+    {
+        clap_track_info clapTrackInfo {};
+        if (_host.trackInfoGet(&clapTrackInfo))
+        {
+            juce::AudioProcessor::TrackProperties juceTrackInfo{};
+
+            if (clapTrackInfo.flags & CLAP_TRACK_INFO_HAS_TRACK_NAME)
+            {
+                juceTrackInfo.name = juce::CharPointer_UTF8(clapTrackInfo.name);
+            }
+            if (clapTrackInfo.flags & CLAP_TRACK_INFO_HAS_TRACK_COLOR)
+            {
+                juceTrackInfo.colour = clapColourToJUCEColour(clapTrackInfo.color);
+            }
+
+            processor->updateTrackProperties(juceTrackInfo);
+        }
+    }
+
+    bool implementsParamIndication() const noexcept override
+    {
+        if (processorAsClapExtensions)
+            return processorAsClapExtensions->supportsParamIndication();
+        return false;
+    }
+    void paramIndicationSetMapping(clap_id param_id, bool has_mapping, const clap_color_t *color,
+                                   const char *label, const char *description) noexcept override
+    {
+        if (!processorAsClapExtensions)
+            return;
+
+        const auto &param = paramPtrByClapID[param_id];
+
+        juce::Colour juceColour{};
+        if (color != nullptr)
+            juceColour = clapColourToJUCEColour(*color);
+        const juce::Colour *juceColourPtr = color == nullptr ? nullptr : &juceColour;
+
+        juce::String labelStr{};
+        if (label != nullptr)
+            labelStr = (juce::CharPointer_UTF8)label;
+
+        juce::String descStr{};
+        if (label != nullptr)
+            descStr = (juce::CharPointer_UTF8)description;
+
+        processorAsClapExtensions->paramIndicationSetMapping(*param.rangedParameter, has_mapping,
+                                                             juceColourPtr, labelStr, descStr);
+    }
+    void paramIndicationSetAutomation(clap_id param_id, uint32_t automation_state,
+                                      const clap_color_t *color) noexcept override
+    {
+        if (!processorAsClapExtensions)
+            return;
+
+        const auto &param = paramPtrByClapID[param_id];
+
+        juce::Colour juceColour{};
+        if (color != nullptr)
+            juceColour = clapColourToJUCEColour(*color);
+        const juce::Colour *juceColourPtr = color == nullptr ? nullptr : &juceColour;
+
+        processorAsClapExtensions->paramIndicationSetAutomation(*param.rangedParameter,
+                                                                automation_state, juceColourPtr);
+    }
+
     bool implementRemoteControls() const noexcept override
     {
         if (processorAsClapExtensions)
@@ -1181,8 +1274,13 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
         if (paramVariant.processorParam->isAutomatable())
             info->flags = info->flags | CLAP_PARAM_IS_AUTOMATABLE;
 
-        if (paramVariant.processorParam->isBoolean() || paramVariant.processorParam->isDiscrete())
+        if (paramVariant.processorParam->isBoolean())
         {
+            // This condition used to say || paramVariant.processorParam->isDiscrete())
+            // but AudioProcessorChoice and Int normalize to 0...1 in
+            // JUCE so this ends up breaking the built in controls
+            // at the edge in CLAP vs VST3
+
             info->flags = info->flags | CLAP_PARAM_IS_STEPPED;
         }
 
@@ -1391,8 +1489,17 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
          */
         static constexpr uint32_t maxBuses = 128;
         std::array<float *, maxBuses> busses{};
+        std::array<double *, maxBuses> doubleBusses{};
         busses.fill(nullptr);
 
+        bool supportsDouble = processor->supportsDoublePrecisionProcessing();
+        bool hostCalledWithDouble = false;
+
+        if (supportsDouble)
+        {
+            doubleBusses.fill(nullptr);
+        }
+
         // we can't advance `n` until we know how many samples we're processing,
         // so we'll increment it inside the loop.
         for (int n = 0; n < numSamples;)
@@ -1462,7 +1569,15 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
             {
                 for (uint32_t ch = 0; ch < process->audio_outputs[idx].channel_count; ++ch)
                 {
-                    busses[outputChannels] = process->audio_outputs[idx].data32[ch] + n;
+                    if (supportsDouble && process->audio_outputs[idx].data64 != nullptr)
+                    {
+                        doubleBusses[outputChannels] = process->audio_outputs[idx].data64[ch] + n;
+                        hostCalledWithDouble = true;
+                    }
+                    else
+                    {
+                        busses[outputChannels] = process->audio_outputs[idx].data32[ch] + n;
+                    }
                     outputChannels++;
                 }
             }
@@ -1473,40 +1588,84 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
             {
                 for (uint32_t ch = 0; ch < process->audio_inputs[idx].channel_count; ++ch)
                 {
-                    auto *ic = process->audio_inputs[idx].data32[ch] + n;
-                    if (inputChannels < outputChannels)
+                    if (supportsDouble && process->audio_inputs[idx].data64 != nullptr)
                     {
-                        if (ic == busses[inputChannels])
+                        auto *ic = process->audio_inputs[idx].data64[ch] + n;
+                        if (inputChannels < outputChannels)
                         {
-                            // The buffers overlap - no need to do anything
+                            if (ic == doubleBusses[inputChannels])
+                            {
+                                // The buffers overlap - no need to do anything
+                            }
+                            else
+                            {
+                                juce::FloatVectorOperations::copy(doubleBusses[inputChannels], ic,
+                                                                  numSamplesToProcess);
+                            }
                         }
                         else
                         {
-                            juce::FloatVectorOperations::copy(busses[inputChannels], ic,
-                                                              numSamplesToProcess);
+                            doubleBusses[inputChannels] = ic;
                         }
+                        hostCalledWithDouble = true;
                     }
                     else
                     {
-                        busses[inputChannels] = ic;
+                        auto *ic = process->audio_inputs[idx].data32[ch] + n;
+                        if (inputChannels < outputChannels)
+                        {
+                            if (ic == busses[inputChannels])
+                            {
+                                // The buffers overlap - no need to do anything
+                            }
+                            else
+                            {
+                                juce::FloatVectorOperations::copy(busses[inputChannels], ic,
+                                                                  numSamplesToProcess);
+                            }
+                        }
+                        else
+                        {
+                            busses[inputChannels] = ic;
+                        }
                     }
                     inputChannels++;
                 }
             }
 
             auto totalChans = juce::jmax(inputChannels, outputChannels);
-            juce::AudioBuffer<float> buffer(busses.data(), (int)totalChans, numSamplesToProcess);
-
-            if (processor->isSuspended())
+            if (hostCalledWithDouble)
             {
-                buffer.clear();
+                juce::AudioBuffer<double> buffer(doubleBusses.data(), (int)totalChans,
+                                                numSamplesToProcess);
+
+                if (processor->isSuspended())
+                {
+                    buffer.clear();
+                }
+                else
+                {
+                    FIXME("Handle bypass and deactivated states")
+                    processor->processBlock(buffer, midiBuffer);
+                }
             }
             else
             {
-                FIXME("Handle bypass and deactivated states")
-                processor->processBlock(buffer, midiBuffer);
+                juce::AudioBuffer<float> buffer(busses.data(), (int)totalChans,
+                                                numSamplesToProcess);
+
+                if (processor->isSuspended())
+                {
+                    buffer.clear();
+                }
+                else
+                {
+                    FIXME("Handle bypass and deactivated states")
+                    processor->processBlock(buffer, midiBuffer);
+                }
             }
 
+
             if (processorAsClapExtensions && processorAsClapExtensions->supportsOutboundEvents())
             {
                 processorAsClapExtensions->addOutboundEventsToQueue(process->out_events, midiBuffer,
@@ -2209,6 +2368,7 @@ class ClapJuceWrapper : public clap::helpers::Plugin<
     bool hasTransportInfo{false};
 };
 
+JUCE_END_IGNORE_WARNINGS_GCC_LIKE
 JUCE_END_IGNORE_WARNINGS_MSVC
 
 const char *features[] = {CLAP_FEATURES, nullptr};
